@@ -63,14 +63,18 @@ class ContextUpdater:
         # In case the user has just entered the skill,
         # we call the _initial_state_ function.
         elif 'state' not in self.context:
-            self._initial_state_()
+            state_response = self._initial_state_()
+            if state_response and type(state_response) == str:
+                self.response.out_text = state_response
         # In case the user already has a state.
         else:
             state = self.next_state.split('ContextUpdater_', maxsplit=1)[1]
             if state not in self.states:
                 raise Exception(f"State {state} not registered!")
             else:
-                self.states[state](self)
+                state_response = self.states[state](self)
+                if state_response and type(state_response) == str:
+                    self.response.out_text = state_response
         # Save vault updated data
         if self.vault:
             self.context['__vault__'] = self.vault.dict()
@@ -98,7 +102,7 @@ class ContextUpdater:
                 'Response out_text field is None inside non-action state!')
         return self.response
 
-    def _initial_state_(self):
+    def _initial_state_(self) -> None or str:
         """Execute when state is None"""
         self.response.out_text = "Добро пожаловать в фреймворк Scintillant." \
                                  "\n\n" \
